@@ -3,4 +3,4 @@ try:
 except ImportError:
     pass
 from views import OfferMakerDispatcher
-from core import OfferMakerCore
\ No newline at end of file
+from core import OfferMakerCore, NoMatchingVariantsException
\ No newline at end of file
